## Uname_sridhar is a wrapper of uname Linux Command

#### Prerequisites


On Ubuntu/Debian:

```
sudo apt install update
sudo apt install upgrade
```



#### Usage

To get all available info about Linux Commands and Type of Linux Commands
```
 Uname [Option..]

```
